# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .hs_code_agg_bucket import HsCodeAggBucket
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class HsCodeAggTerms(UniversalBaseModel):
    doc_count_error_upper_bound: int
    sum_other_doc_count: int
    buckets: typing.List[HsCodeAggBucket]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
